==> manage-3.1.0-40.jar: management/sqls/webmeter/getAllLoseQuery.sql <==
select * from(
select
   m3.f_userinfo_id,
   m3.f_userinfo_code,  --客户编号
   m3.f_user_name,      --客户名称
   m2.f_address,         --客户地址
   m1.f_meternumber,     --表号
   isnull(isnull(m1.f_startuse_date,m1.f_gas_date),m1.f_input_date) f_startuse_date,   --启用日期
   case
   when m5.max_interval_day is null then DATEDIFF(dd,'{startDate}','{endDate}')
   when m5.max_interval_day>DATEDIFF(dd,m5.last_date,'{endDate}') then m5.max_interval_day
   else DATEDIFF(dd,m5.last_date,'{endDate}') end max_interval_day,                   --最长失联间隔 .上报记录里最大间隔>最后一次上报时间距离结束时间段，取后者，否则取前者

   case
   when init_date<'{startDate}' then DATEDIFF(dd,'{startDate}','{endDate}')
   else DATEDIFF(dd,m6.init_date,'{endDate}') end  YBdays, --应报天数.如果初次上报小于起始时间，那整个区间就是应报天数，否则就是结束时间减初次上报
   isnull(m5.SBdays,0) SBdays,                                                                            --实报天数
   case
   when init_date<'{startDate}' then DATEDIFF(dd,'{startDate}','{endDate}')- isnull(m5.SBdays,0)
   else DATEDIFF(dd,m6.init_date,'{endDate}')-isnull(m5.SBdays,0) end  SLdays,	                 --累计失联天数
   m1.f_orgid,                          --组织ID
   m1.f_orgname,                        --组织名称
   m1.f_user_type,                      --客户类型
   m1.f_gasproperties,					--用气性质
   m4.f_meter_brand,                    --气表品牌
   m1.f_table_state                     --气表状态
 from
 t_userfiles m1
 left join  t_user_address m2  on m1.f_useraddress_id=m2.id
 left join  t_userinfo m3 on m1.f_userinfo_id=m3.f_userinfo_id
 left join  t_gasbrand m4 on m1.f_gasbrand_id=m4.id
 left join
  (
	select
	    f_userfiles_id,
	  	COUNT(*)   SBdays,               --总共上报天数
		max(last_date) last_date,        --区间内最后报时间
		MAX(max_interval_day) max_interval_day   --区间内最大间隔时间
	from (
		select f_userfiles_id,
			max(f_insert_date) last_date,        --区间内最后报时间
			MAX(interval_day) max_interval_day   --区间内最大间隔时间
	    from (
			select
				f_userfiles_id,
				f_insert_date,
				case
				when f_last_insertdate is null then 1
				else DATEDIFF(dd,f_last_insertdate,f_insert_date) end  interval_day --拿到每条上报时间据上次的时间间隔，第一条上报间隔算1天
			from t_meteread where f_insert_date>='{startDate}' and f_insert_date<='{endDate}'
		) ss group by f_userfiles_id,left(convert(varchar,f_insert_date,21),10) --同一天多次上报算一条
	) xx group by f_userfiles_id
  ) m5  on m1.f_userfiles_id=m5.f_userfiles_id
  left join
  (
   select f_userfiles_id,min(f_insert_date) init_date from t_meteread where f_insert_date<'{endDate}' group by f_userfiles_id  --只拿区间结束时间前上报过的表和表初次上报时间
  ) m6 on  m1.f_userfiles_id=m6.f_userfiles_id
 where m1.f_meter_classify='物联网表'  and f_table_state='正常'
 and isnull(isnull(m1.f_startuse_date,m1.f_gas_date),f_input_date)<='{endDate}' --过滤结束时间后的开户表
 and m6.init_date is not null                                                --过滤期间未上报过的表
 )s where  {condition}
 ORDER BY f_userinfo_code

==> manage-3.1.0-44.jar: management/sqls/webmeter/getAllLoseQuery.sql <==
select * from(
select
   m3.f_userinfo_id,
   m3.f_userinfo_code,  --客户编号
   m3.f_user_name,      --客户名称
   m2.f_address,         --客户地址
   m1.f_meternumber,     --表号
   isnull(isnull(m1.f_startuse_date,m1.f_gas_date),m1.f_input_date) f_startuse_date,   --启用日期
   case
   when m5.max_interval_day is null then DATEDIFF(dd,'{startDate}','{endDate}')+1
   when m5.max_interval_day>DATEDIFF(dd,m5.last_date,'{endDate}')+1 then m5.max_interval_day
   else DATEDIFF(dd,m5.last_date,'{endDate}')+1 end max_interval_day,                   --最长失联间隔 .上报记录里最大间隔>最后一次上报时间距离结束时间段，取后者，否则取前者

   case
   when init_date<'{startDate}' then DATEDIFF(dd,'{startDate}','{endDate}')+1
   else DATEDIFF(dd,m6.init_date,'{endDate}')+1 end  YBdays, --应报天数.如果初次上报小于起始时间，那整个区间就是应报天数，否则就是结束时间减初次上报
   isnull(m5.SBdays,0) SBdays,                                                                            --实报天数
   case
   when init_date<'{startDate}' then (DATEDIFF(dd,'{startDate}','{endDate}')+1) - isnull(m5.SBdays,0)
   else (DATEDIFF(dd,m6.init_date,'{endDate}')-isnull(m5.SBdays,0)+1) end  SLdays,	                 --累计失联天数
   m1.f_orgid,                          --组织ID
   m1.f_orgname,                        --组织名称
   m1.f_user_type,                      --客户类型
   m1.f_gasproperties,					--用气性质
   m4.f_meter_brand,                    --气表品牌
   m1.f_table_state                     --气表状态
 from
 t_userfiles m1
 left join  t_user_address m2  on m1.f_useraddress_id=m2.id
 left join  t_userinfo m3 on m1.f_userinfo_id=m3.f_userinfo_id
 left join  t_gasbrand m4 on m1.f_gasbrand_id=m4.id
 left join
  (
	select
	    f_userfiles_id,
	  	COUNT(*)   SBdays,               --总共上报天数
		max(last_date) last_date,        --区间内最后报时间
		MAX(max_interval_day) max_interval_day   --区间内最大间隔时间
	from (
		select f_userfiles_id,
			max(f_insert_date) last_date,        --区间内最后报时间
			MAX(interval_day) max_interval_day   --区间内最大间隔时间
	    from (
			select
				f_userfiles_id,
				f_insert_date,
				case
				when f_last_insertdate is null then 1
				else DATEDIFF(dd,f_last_insertdate,f_insert_date) end  interval_day --拿到每条上报时间据上次的时间间隔，第一条上报间隔算1天
			from t_meteread where f_insert_date>='{startDate}' and f_insert_date<='{endDate}'
		) ss group by f_userfiles_id,left(convert(varchar,f_insert_date,21),10) --同一天多次上报算一条
	) xx group by f_userfiles_id
  ) m5  on m1.f_userfiles_id=m5.f_userfiles_id
  left join
  (
   select f_userfiles_id,min(f_insert_date) init_date from t_meteread where f_insert_date<'{endDate}' group by f_userfiles_id  --只拿区间结束时间前上报过的表和表初次上报时间
  ) m6 on  m1.f_userfiles_id=m6.f_userfiles_id
 where m1.f_meter_classify='物联网表'  and f_table_state='正常'
 and isnull(isnull(m1.f_startuse_date,m1.f_gas_date),f_input_date)<='{endDate}' --过滤结束时间后的开户表
 and m6.init_date is not null                                                --过滤期间未上报过的表
 )s where  {condition}
 ORDER BY f_userinfo_code
